@@ -2,11 +2,12 @@
 __author__ = "Damon May"
 
 import seaborn as sns
+from typing import Any
 from jamstats.data.game_data import DerbyGame
 import logging
 from matplotlib import pyplot as plt
 
-logger = logging.Logger(__name__, level=logging.DEBUG)
+logger = logging.Logger(__name__)
 
 DEFAULT_THEME = "white"
 
@@ -18,6 +19,8 @@ VALID_THEMES = [
     "ticks"
 ]
 
+resource_file_dict = {
+}
 
 def prepare_to_plot(theme:str = DEFAULT_THEME) -> None:
     """Prepare Seaborn to make pretty plots.
@@ -32,5 +35,4 @@ def prepare_to_plot(theme:str = DEFAULT_THEME) -> None:
 
 
 def make_team_color_palette(derby_game: DerbyGame):
-    return sns.color_palette([derby_game.team_color_1, derby_game.team_color_2])
-
+    return sns.color_palette([derby_game.team_color_1, derby_game.team_color_2])
\ No newline at end of file
